<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :xl="4"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="备件分类">
              <j-dict-select-tag
                allow-clear
                :disabled="false"
                placeholder="请选择备件分类"
                :triggerChange="true"
                dictCode="spare_part_category"
                v-model="queryParam.partCategory"
              />
            </a-form-item>
          </a-col>
          <a-col
            :xl="4"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="备件编码">
              <j-input
                placeholder="请输入备件编码"
                v-model="queryParam.partCode"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl="4"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="备件名称">
              <j-input
                placeholder="请输入备件名称"
                v-model="queryParam.partName"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl="4"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="备件型号">
              <j-input
                placeholder="请输入备件型号"
                v-model="queryParam.partModel"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl="4"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>

      <a-button
        @click="handleInto"
        type="primary"
        icon="plus"
      >入库</a-button>
      <!-- <a-button
        type="primary"
        icon="download"
        @click="handleExportXls('备品备件管理')"
      >导出</a-button>
      <a-upload
        name="file"
        :showUploadList="false"
        :multiple="false"
        :headers="tokenHeader"
        :action="importExcelUrl"
        @change="handleImportExcel"
      >
        <a-button
          type="primary"
          icon="import"
        >导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item
            key="1"
            @click="batchDel"
          ><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        :customRow='clickThenSelect'
        @change="handleTableChange"
      >

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a-popconfirm
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
      <a-tabs defaultActiveKey="1">
        <a-tab-pane
          tab='库存明细'
          key="1"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <eamSpare-part-inventory-list :sparePartId='sparePartId' />
          </div>
        </a-tab-pane>
      </a-tabs>
    </div>
    <!-- table区域-end -->

    <eamSpareParts-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></eamSpareParts-modal>

    <eamSpare-part-into-modal
      ref="intoModalForm"
      @ok="modalFormOk"
    ></eamSpare-part-into-modal>
  </a-card>
</template>

<script>
import '@assets/less/TableExpand.less'
import EamSparePartsModal from './modules/EamSpareParts/EamSparePartsModal.vue'
import EamSparePartInventoryList from './modules/EamSpareParts/EamSparePartInventoryList.vue'
import EamSparePartIntoModal from './modules/EamSpareParts/EamSparePartIntoModal.vue'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: "EamSparePartsList",
  mixins: [JeecgListMixin],
  components: {
    EamSparePartsModal,
    EamSparePartInventoryList,
    EamSparePartIntoModal
  },
  data() {
    return {
      description: '备品备件管理页面',
      sparePartId: '-1',
      // 表头
      columns: [
        {
          title: '备件编码',
          align: "center",
          dataIndex: 'partCode'
        },
        {
          title: '分类',
          align: "center",
          dataIndex: 'partCategory_dictText'
        },
        {
          title: '备件名称',
          align: "center",
          dataIndex: 'partName'
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'partModel'
        },
        {
          title: '规格',
          align: "center",
          dataIndex: 'partSpecification'
        },
        {
          title: '存放仓库',
          align: "center",
          dataIndex: 'storehouse'
        },
        {
          title: '制造商',
          align: "center",
          dataIndex: 'manufacturingEnterprise'
        },
        {
          title: '单位',
          align: "center",
          dataIndex: 'unit'
        },
        {
          title: '有效期（天）',
          align: "center",
          dataIndex: 'periodOfValidity'
        },
        {
          title: '库存上限值',
          align: "center",
          dataIndex: 'inventoryMax'
        },
        {
          title: '库存下限值',
          align: "center",
          dataIndex: 'inventoryMin'
        },
        {
          title: '库存预警值',
          align: "center",
          dataIndex: 'inventoryWarning'
        },
        {
          title: '库存总数',
          align: "center",
          dataIndex: 'totalQuantity'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          scopedSlots: { customRender: 'action' },
        }
      ],
      url: {
        list: "/eam/eamSpareParts/list",
        delete: "/eam/eamSpareParts/delete",
        deleteBatch: "/eam/eamSpareParts/deleteBatch",
        exportXlsUrl: "eam/eamSpareParts/exportXls",
        importExcelUrl: "eam/eamSpareParts/importExcel",
      },
    }
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    }
  },
  methods: {

    handleInto() {
      this.$refs.intoModalForm.add();
      this.$refs.intoModalForm.title = "入库";
    },
    searchReset() {
      this.queryParam = {}
      this.onClearSelected()
      this.loadData(1);
    },
    searchQuery() {
      this.onClearSelected()
      this.loadData(1);
    },
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.sparePartId = '-1'
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.sparePartId = selectionRows[0]['id']
      } else {
        this.sparePartId = '-1'
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>